GeomKodomBranch: Geom for geom_kodom_branch

GeomKodomBranchR Documentation

Geom for geom_kodom_branch

Description

Extends ggplot2::GeomPath to draw branching trajectory plots. In addition to the interpolated colour-gradient path (via .kodom_build_segments()), draws a short vertical fork connector at each subject's branch point — the first x that appears in a predicted arm — connecting the observed lane to the topmost prediction arm. Toggle with show_fork.

Usage

GeomKodomBranch

Format

A ggproto object.


ggkodom documentation built on June 20, 2026, 5:06 p.m.