| GeomKodomBranch | R Documentation |
Extends ggplot2::GeomPath to draw branching trajectory plots. In addition
to the interpolated colour-gradient path (via .kodom_build_segments()),
draws a short vertical fork connector at each subject's branch point —
the first x that appears in a predicted arm — connecting the observed lane
to the topmost prediction arm. Toggle with show_fork.
GeomKodomBranch
A ggproto object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.