| StatKodomCircular | R Documentation |
Assigns lane positions, maps each lane to an angular position and the
time variable to a radial position, then converts to Cartesian
coordinates for rendering in ordinary Cartesian space (no coord_polar).
Called automatically by geom_kodom_circular(); rarely needed directly.
StatKodomCircular
A ggproto object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.